@@ -2,7 +2,7 @@ import os
 import glob
 
 import logging
-log = logging.getLogger("pap.Audiobook")
+log = logging.getLogger("nqaap.Audiobook")
 
 
 class Audiobook:
