@@ -6,4 +6,7 @@ config_dir = os.path.join(user_dir,".nqaap/")
 book_dir = os.path.join(user_dir,"MyDocs/Audiobooks/")
 
 def get_books():
-    return [f for f in os.listdir(book_dir) if os.path.isdir(os.path.join(book_dir, f))]
+    try:
+        return [f for f in os.listdir(book_dir) if os.path.isdir(os.path.join(book_dir, f))]
+    except OSError:
+        return []
