@@ -27,8 +27,8 @@ class Player:
             
     def set_book(self, book):
         self.storage.select_book(book)
-        chapter, time = self.storage.get_time()
-        self.audiobook = Audiobook.Audiobook(os.path.join(Paths.book_dir , book), chapter)
+        chapter_num, time = self.storage.get_time()
+        self.audiobook = Audiobook.Audiobook(os.path.join(Paths.book_dir , book), chapter_num)
         
         # self.player.set_file(self.audiobook.get_current_chapter())
         # self.player.seek_time(time) 
@@ -37,14 +37,15 @@ class Player:
             self.ui.set_book(book, self.audiobook.get_cover_img())
             self.ui.set_chapters(self.audiobook.chapters)
 
-        chapter_title = self.audiobook.chapters[chapter]
-        self.set_chapter(chapter_title)
+        chapter_title = self.audiobook.chapters[chapter_num]
+        self.set_chapter(chapter_title,True)
 
-    def set_chapter(self, chapter):
-        log.info("set chapter:" + chapter)
+    def set_chapter(self, chapter, continuing = False):
+        log.info("set chapter:" + chapter + " : Continuing: " + str(continuing))
         self.audiobook.set_chapter(chapter)
         self.player.set_file(self.audiobook.get_current_chapter())
-        self.storage.set_time(self.audiobook.current_chapter,0)
+        if not continuing:
+            self.storage.set_time(self.audiobook.current_chapter,0)
         
         if self.ui is not None:
             self.ui.set_chapter(self.audiobook.current_chapter)
@@ -123,45 +124,3 @@ class Player:
     #     raise Exception("this function should not be used")
     #     return {c[0:-4] for c in self.audiobook.chapters}
         
-
-def main():
-
-    s = SornPlayer(threaded = True)
-    
-    import sys
-    timer = 0 
-    if len(sys.argv) > 1:               # book argument
-        path = os.path.join(Paths.book_dir, sys.argv[1])
-        #print "staring book from ", path
-        try:
-
-            timer = int(sys.argv[1])
-            print "first argument is timer, so we continue the book we already have"
-        except:
-            
-            if os.path.isdir(path):
-                s.set_book(sys.argv[1])
-            else:
-                print "there does not seem to be a book that fits the given name"
-
-    s.play()
-                         
-    if len(sys.argv) > 2:               # sleeptime argument
-        # print "sleepage: ", sys.argv[2]
-        timer = int(sys.argv[2])
-    else:
-        print "no sleeptime"
-
-    if timer > 0:
-        s.start_sleeptimer(timer * 60 ) 
-        
-    i = 1
-    while s.is_playing():
-        time.sleep(1)
-        print i
-        i = i + 1
-
-    print "now we were ended"
-    
-if __name__ == "__main__":
-    main()
